@@ -18,6 +18,10 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
+#ifdef HAVE_CONFIG_H
+#  include <config.h>
+#endif
+
 /* CDF is evil. There is only one outdated specification of it and its
    example is not even well-formed XML! Also, it seems to rely on
    things being case insensitive. Some people seem to make the tags
@@ -153,8 +157,16 @@ static void cdf_parse(feedPtr fp, xmlDocPtr doc, xmlNodePtr cur) {
 }
 
 gboolean cdf_format_check(xmlDocPtr doc, xmlNodePtr cur) {
+		
+	/* avoid mistaking RSS 1.1 which also uses "Channel" as root tag */
+	if((NULL != cur->ns) &&
+	   (NULL != cur->ns->href) &&
+	   !xmlStrcmp(cur->ns->href, BAD_CAST"http://purl.org/net/rss1.1#"))
+	   	return FALSE;
+		
 	if(!xmlStrcasecmp(cur->name, BAD_CAST"Channel"))
 		return TRUE;
+		
 	return FALSE;
 }
 
