@@ -18,8 +18,8 @@
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
 
-#ifndef _CDF_CDF_ITEM_H
-#define _CDF_CDF_ITEM_H
+#ifndef _CDF_ITEM_H
+#define _CDF_ITEM_H
 
 #include <time.h>
 #include <glib.h>
@@ -28,17 +28,7 @@
 
 #include "cdf_channel.h"
 
-#define CDF_ITEM_TITLE		0
-#define CDF_ITEM_DESCRIPTION	1
-#define CDF_ITEM_LINK		2
-#define CDF_ITEM_AUTHOR		3
-#define CDF_ITEM_IMAGE		4
-#define CDF_ITEM_CATEGORY	5
-	
-#define CDF_ITEM_MAX_TAG	6
-
 typedef struct CDFItem {
-	gchar		*tags[CDF_ITEM_MAX_TAG];	/* standard namespace infos */
 	
 	GHashTable	*nsinfos;	/* list to store pointers to namespace
 					   specific informations */	
