@@ -1,8 +1,8 @@
 /**
  * @file common.c common routines for Liferea
  * 
- * Copyright (C) 2003, 2004 Lars Lindner <lars.lindner@gmx.net>
- * Copyright (C) 2004       Nathan J. Conrad <t98502@users.sourceforge.net>
+ * Copyright (C) 2003-2005  Lars Lindner <lars.lindner@gmx.net>
+ * Copyright (C) 2004,2005  Nathan J. Conrad <t98502@users.sourceforge.net>
  * Copyright (C) 2004       Karl Soderstrom <ks@xanadunet.net>
  *
  * parts of the RFC822 timezone decoding were taken from the gmime 
@@ -28,12 +28,16 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
+#ifdef HAVE_CONFIG_H
+#  include <config.h>
+#endif
+
 #define _XOPEN_SOURCE /* glibc2 needs this (man strptime) */
-#include <config.h>
 
 #include <libxml/xmlerror.h>
 #include <libxml/uri.h>
 #include <libxml/parser.h>
+#include <libxml/entities.h>
 #include <libxml/HTMLparser.h>
 #include <glib.h>
 #include <sys/stat.h>
@@ -61,11 +65,11 @@ void addToHTMLBufferFast(gchar **buffer, const gchar *string) {
 		return;
 	
 	if(NULL != *buffer) {
-		int oldlength = strlen(*buffer);
-		int newlength = strlen(string);
-		int allocsize = (((oldlength+newlength+1)/512)+1)*512; /* Round up to nearest 512 KB */
+		gulong oldlength = strlen(*buffer);
+		gulong newlength = strlen(string);
+		gulong allocsize = (((oldlength+newlength+1L)/512L)+1L)*512L; /* Round up to nearest 512 KB */
 		*buffer = g_realloc(*buffer, allocsize);
-		g_memmove(&((*buffer)[oldlength]), string, newlength+1 );
+		g_memmove(&((*buffer)[oldlength]), string, newlength+1L );
 	} else {
 		*buffer = g_strdup(string);
 	}
@@ -77,11 +81,11 @@ void addToHTMLBuffer(gchar **buffer, const gchar *string) {
 		return;
 	
 	if(NULL != *buffer) {
-		int oldlength = strlen(*buffer);
-		int newlength = strlen(string);
-		int allocsize = (oldlength+newlength+1);
+		gulong oldlength = strlen(*buffer);
+		gulong newlength = strlen(string);
+		gulong allocsize = (oldlength+newlength+1L);
 		*buffer = g_realloc(*buffer, allocsize);
-		g_memmove(&((*buffer)[oldlength]), string, newlength+1 );
+		g_memmove(&((*buffer)[oldlength]), string, newlength+1L );
 	} else {
 		*buffer = g_strdup(string);
 	}
@@ -282,41 +286,32 @@ static void bufferParseError(void *ctxt, const gchar * msg, ...) {
 	}
 }
 
-static GHashTable *extra_entities = NULL;
+static xmlDocPtr entities = NULL;
 
 /* and I thought writing such functions is evil... */
 xmlEntityPtr common_process_entities(void *ctxt, const xmlChar *name) {
-	xmlEntityPtr	entity;
-	gchar		*text;
+	xmlEntityPtr	entity, found;
+	xmlChar		*tmp;
 	
 	entity = xmlGetPredefinedEntity(name);
 	if(NULL == entity) {
-		if(NULL == extra_entities) {
-			extra_entities = g_hash_table_new(g_str_hash, g_str_equal);
-			/* attention! ensure UTF-8 for the following definitions! */
-			g_hash_table_insert(extra_entities, "nbsp", " ");
-			g_hash_table_insert(extra_entities, "auml", "ä");
-			g_hash_table_insert(extra_entities, "Auml", "Ä");
-			g_hash_table_insert(extra_entities, "uuml", "ü");
-			g_hash_table_insert(extra_entities, "Uuml", "Ü");
-			g_hash_table_insert(extra_entities, "ouml", "ö");
-			g_hash_table_insert(extra_entities, "Ouml", "Ö");
-			g_hash_table_insert(extra_entities, "szlig", "ß");
-			g_hash_table_insert(extra_entities, "copy", "©");
-			g_hash_table_insert(extra_entities, "hellip", "…");
-			g_hash_table_insert(extra_entities, "laquo", "«");
-			g_hash_table_insert(extra_entities, "raquo", "»");
-			// FIXME: someone who want's to add all other HTML entity definitions?
-			// or better somehow load a DTD and serve entities when necessary...
+		if(NULL == entities) {
+			/* loading HTML entities */
+			entities = xmlNewDoc(BAD_CAST "1.0");
+			xmlCreateIntSubset(entities, BAD_CAST "HTML entities", NULL, PACKAGE_DATA_DIR "/" PACKAGE "/dtd/html.ent");
+			entities->extSubset = xmlParseDTD(entities->intSubset->ExternalID, entities->intSubset->SystemID);
 		}
-		if(NULL != (text = g_hash_table_lookup(extra_entities, name))) {
+		
+		if(NULL != (found = xmlGetDocEntity(entities, name))) {
 			/* returning as faked predefined entity... */
+			tmp = xmlStrdup(found->content);
+			tmp = unhtmlize(tmp);	/* arghh ... slow... */
 			entity = (xmlEntityPtr)g_new0(xmlEntity, 1);
 			entity->type = XML_ENTITY_DECL;
 			entity->name = name;
-			entity->orig = text;	/* ??? */
-			entity->content = text;
-			entity->length = g_utf8_strlen(text, -1);
+			entity->orig = tmp;	/* ??? */
+			entity->content = tmp;
+			entity->length = g_utf8_strlen(tmp, -1);
 			entity->etype = XML_INTERNAL_PREDEFINED_ENTITY;
 		}
 	}
@@ -374,10 +369,11 @@ xmlDocPtr parseBuffer(gchar *data, size_t dataLength, gchar **errormsg) {
 	   GtkHTML2 module is not unhappy because it also tries to call the
 	   errorfunc on occasion. */
 	xmlSetGenericErrorFunc(NULL, NULL);
-	
+
 	*errormsg = errors->buffer;
 	g_free(errors);
 	xmlFreeParserCtxt(ctxt);
+	
 	return doc;
 }
 
@@ -388,6 +384,8 @@ time_t parseISO8601Date(gchar *date) {
 	gboolean	success = FALSE;
 	gchar *pos;
 	
+	g_assert(date != NULL);
+	
 	memset(&tm, 0, sizeof(struct tm));
 	
 	/* we expect at least something like "2003-08-07T15:28:19" and
@@ -405,7 +403,7 @@ time_t parseISO8601Date(gchar *date) {
 			tm.tm_sec = pos[0] - '0';
 			pos++;
 		} else if (isdigit(pos[0]) && isdigit(pos[1])) {
-			tm.tm_sec = 10*(pos[0]-'0') + pos[0] - '0';
+			tm.tm_sec = 10*(pos[0]-'0') + pos[1] - '0';
 			pos +=2;
 		}
 		/* Parse timezone */
@@ -615,7 +613,7 @@ gchar * common_create_cache_filename( const gchar *folder, const gchar *key, con
 
 static gchar * byte_to_hex(unsigned char nr) {
 	gchar *result = NULL;
-	
+
 	result = g_strdup_printf("%%%x%x", nr / 0x10, nr % 0x10);
 	return result;
 }
@@ -636,7 +634,7 @@ gchar * encode_uri_string(gchar *string) {
 		else if(string[i] == ' ')
 			tmp = g_strdup_printf("%s%%20", newURIString);
 		else if((unsigned char)string[i] <= 127) {
-			tmp = g_strdup_printf(newURIString, hex = byte_to_hex(string[i]));g_free(hex);
+			tmp = g_strdup_printf("%s%s", newURIString, hex = byte_to_hex(string[i]));g_free(hex);
 		} else {
 			bytes = 0;
 			if(((unsigned char)string[i] >= 192) && ((unsigned char)string[i] <= 223))
@@ -708,11 +706,6 @@ xmlChar * common_build_url(const gchar *url, const gchar *baseURL) {
 	return absURL;
 }
 
-gchar * filter_title(gchar * title) {
-
-	return g_strstrip(title);
-}
-
 #ifndef HAVE_STRSEP
 /* code taken from glibc-2.2.1/sysdeps/generic/strsep.c */
 char* strsep (char **stringp, const char *delim) {
