@@ -1,8 +1,8 @@
 /**
  * @file common.h common routines
  *
- * Copyright (C) 2003, 2004 Lars Lindner <lars.lindner@gmx.net>
- * Copyright (C) 2004 Nathan J. Conrad <t98502@users.sourceforge.net>
+ * Copyright (C) 2003-2005 Lars Lindner <lars.lindner@gmx.net>
+ * Copyright (C) 2004,2005 Nathan J. Conrad <t98502@users.sourceforge.net>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -125,15 +125,6 @@ xmlChar * common_uri_escape(const xmlChar *url);
  */
 xmlChar * common_build_url(const gchar *url, const gchar *baseURL);
 
-/**
- * Filter the title. Note that the string is modified and not
- * duplicated!
- *
- * @param title		title string be be filtered
- * @returns the result string, which is nearly always the same as the value passed to it.
- */
-gchar * filter_title(gchar * title);
-
 #ifndef HAVE_STRSEP
 char *strsep (char **stringp, const char *delim);
 #endif
