@@ -1,8 +1,8 @@
 /**
  * @file conf.c Liferea configuration (gconf access)
  *
- * Copyright (C) 2003, 2004 Lars Lindner <lars.lindner@gmx.net>
- * Copyright (C) 2004 Nathan J. Conrad <t98502@users.sourceforge.net>
+ * Copyright (C) 2003-2005 Lars Lindner <lars.lindner@gmx.net>
+ * Copyright (C) 2004,2005 Nathan J. Conrad <t98502@users.sourceforge.net>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -89,10 +89,9 @@ static gboolean is_gconf_error(GError **err) {
 
 /* called once on startup */
 void conf_init() {
-	int	ualength;
 	const char	*lang;
 	
-	/* have to be called for multithreaded programs */
+	/* has to be called for multithreaded programs */
 	xmlInitParser();
 	
 	/* the following code was copied from SnowNews and adapted to build
@@ -102,16 +101,11 @@ void conf_init() {
 	   because we need to do it exactly once and it will never change while the program
 	   is running. */
 	if (g_getenv("LANG") != NULL) {
-		lang = g_getenv("LANG");
 		/* e.g. Liferea/0.3.8 (Linux; de_DE; (http://liferea.sf.net/) */
-		ualength = strlen("Liferea/") + strlen(VERSION) + 2 + strlen(lang) + 2 + strlen(OSNAME)+2 + strlen(HOMEPAGE) + 2;
-		useragent = g_malloc(ualength);
-		snprintf (useragent, ualength, "Liferea/%s (%s; %s; %s)", VERSION, OSNAME, lang, HOMEPAGE);
+		useragent = g_strdup_printf("Liferea/%s (%s; %s; %s)", VERSION, OSNAME, g_getenv("LANG"), HOMEPAGE);
 	} else {
 		/* "Liferea/" + VERSION + "(" OS + "; " + HOMEPAGE + ")" */
-		ualength = strlen("Liferea/") + strlen(VERSION) + 2 + strlen(OSNAME) + 2 + strlen("http://liferea.sf.net/") + 2;
-		useragent = g_malloc(ualength);
-		snprintf (useragent, ualength, "Liferea/%s (%s; %s)", VERSION, OSNAME, HOMEPAGE);
+		useragent = g_strdup_printf("Liferea/%s (%s; %s)", VERSION, OSNAME, HOMEPAGE);
 	}
 	
 	/* initialize GConf client */
@@ -138,6 +132,9 @@ void conf_load() {
 	/* check if important preferences exist... */
 	if(0 == (maxitemcount = getNumericConfValue(DEFAULT_MAX_ITEMS)))
 		setNumericConfValue(DEFAULT_MAX_ITEMS, 100);
+		
+	if(0 == strcmp("", getStringConfValue(ENCLOSURE_DOWNLOAD_PATH)))
+		setStringConfValue(ENCLOSURE_DOWNLOAD_PATH, g_getenv("HOME"));
 }
 
 static void conf_tray_settings_cb(GConfClient *client, guint cnxn_id, GConfEntry *entry, gpointer user_data) {
