@@ -1,8 +1,8 @@
 /**
  * @file conf.h Liferea configuration (gconf access)
  *
- * Copyright (C) 2003, 2004 Lars Lindner <lars.lindner@gmx.net>
- * Copyright (C) 2004 Nathan J. Conrad <t98502@users.sourceforge.net>
+ * Copyright (C) 2003-2005 Lars Lindner <lars.lindner@gmx.net>
+ * Copyright (C) 2004,2005 Nathan J. Conrad <t98502@users.sourceforge.net>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -39,6 +39,10 @@
 #define REFOCUS_TIMEOUT			"/apps/liferea/refocus-timeout"
 #define DISABLE_JAVASCRIPT		"/apps/liferea/disable-javascript"
 
+/* enclosure handling */
+#define ENCLOSURE_DOWNLOAD_TOOL		"/apps/liferea/enclosure-download-tool"
+#define ENCLOSURE_DOWNLOAD_PATH		"/apps/liferea/enclosure-download-path"
+
 /* item list settings */
 #define TIME_FORMAT			"/apps/liferea/timeformat"
 #define TIME_FORMAT_MODE		"/apps/liferea/timeformatmode"
@@ -57,6 +61,7 @@
 /* GUI settings and persistency values */
 #define SHOW_TRAY_ICON			"/apps/liferea/trayicon"
 #define SHOW_POPUP_WINDOWS		"/apps/liferea/show-popup-windows"
+#define POPUP_PLACEMENT			"/apps/liferea/popup-placement"
 #define DISABLE_MENUBAR			"/apps/liferea/disable-menubar"
 #define DISABLE_TOOLBAR			"/apps/liferea/disable-toolbar"
 #define LAST_WINDOW_X			"/apps/liferea/last-window-x"
