@@ -19,6 +19,10 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
+#ifdef HAVE_CONFIG_H
+#  include <config.h>
+#endif
+
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <libxml/tree.h>
@@ -546,7 +550,7 @@ void on_import_activate_cb(const gchar *filename, gpointer user_data) {
 
 void on_import_activate(GtkMenuItem *menuitem, gpointer user_data) {
 
-	ui_choose_file(_("Import Feed List"), GTK_WINDOW(mainwindow), _("Import"), FALSE, on_import_activate_cb, NULL, NULL);
+	ui_choose_file(_("Import Feed List"), GTK_WINDOW(mainwindow), _("Import"), FALSE, on_import_activate_cb, NULL, NULL, NULL);
 }
 
 static void on_export_activate_cb(const gchar *filename, gpointer user_data) {
@@ -565,6 +569,6 @@ static void on_export_activate_cb(const gchar *filename, gpointer user_data) {
 
 void on_export_activate(GtkMenuItem *menuitem, gpointer user_data) {
 	
-	ui_choose_file(_("Export Feed List"), GTK_WINDOW(mainwindow), _("Export"), TRUE, on_export_activate_cb, NULL, NULL);
+	ui_choose_file(_("Export Feed List"), GTK_WINDOW(mainwindow), _("Export"), TRUE, on_export_activate_cb, "feedlist.opml", NULL, NULL);
 }
 
