@@ -19,6 +19,10 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
+#ifdef HAVE_CONFIG_H
+#  include <config.h>
+#endif
+
 #include <glib.h>
 #include <libxml/xmlmemory.h>
 #include <libxml/parser.h>
@@ -515,8 +519,11 @@ void feed_schedule_update(feedPtr fp, gint flags) {
 
 	debug1(DEBUG_CONF, "Scheduling %s to be updated", feed_get_title(fp));
 	
+	if(FST_VFOLDER == fp->type)
+		return;
+	
 	if(fp->request != NULL) {
-		ui_mainwindow_set_status_bar(_("This  \"%s\" is already being updated!"), feed_get_title(fp));
+		ui_mainwindow_set_status_bar(_("This feed \"%s\" is already being updated!"), feed_get_title(fp));
 		return;
 	}
 	
