@@ -2,6 +2,7 @@
  * @file feed.h common feed handling
  * 
  * Copyright (C) 2003 Lars Lindner <lars.lindner@gmx.net>
+ * Copyright (C) 2004 Nathan J. Conrad <t98502@users.sourceforge.net>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -34,23 +35,25 @@ enum node_types {
 	FST_INVALID 	= 0,		/**< invalid type */
 	FST_FOLDER 	= 1,		/**< the folder type */
 
-	FST_VFOLDER 	= 9,		/**<special type for VFolders */
-	FST_FEED		= 10,     /**< Any type of feed */
-	FST_HELPFOLDER	= 50,	/**< special tree list types to store help feeds */	
-	FST_HELPFEED	= 51,		/**< special type to allow updating of help feed url */
-
-	FST_AUTODETECT	= 200,	/**< special type to enforce type auto detection */
+	FST_VFOLDER 	= 9,		/**< special type for VFolders */
+	FST_FEED	= 10,		/**< Any type of feed */
 };
 
-/** macro to test whether a type is a resource which is regularly updated */
-#define IS_FEED(type)		((FST_HELPFEED == type) || \
-				 (FST_FEED == type))
-
-/** macro to test whether a type is a folder entry */
-#define IS_FOLDER(type)		((FST_FOLDER == type) || (FST_HELPFOLDER == type))
+/** Flags used in the request structure */
+enum feed_request_flags {
+	FEED_REQ_SHOW_PROPDIALOG = 1,
+	FEED_REQ_RESET_TITLE = 2,	/**< Feed's title should be reset to default upon update */
+	FEED_REQ_RESET_UPDATE_INT = 4,	/**< Feed's update interval should be reset to default upon update */
+	FEED_REQ_AUTO_DISCOVER = 8,	/**< Feed auto-discovery attempts should be made */
+	
+	FEED_REQ_PRIORITY_HIGH = 16,	/**< set to signal that this is an important user triggered request */
+	FEED_REQ_DOWNLOAD_FAVICON = 32, /**< set to make the favicon be updated after the feed is downloaded */
+	FEED_REQ_AUTH_DIALOG = 64,	/**< set to make an auth request dialog to be created after 401 errors */
+	FEED_REQ_NOLOCK = 128		/**< for non-feed requests to avoid locking */
+};
 
 struct feedhandler;
-
+struct request;
 /* ------------------------------------------------------------ */
 /* Feed structure                                               */
 /* ------------------------------------------------------------ */
@@ -63,6 +66,7 @@ enum cache_limit {
 };
 
 /** common structure to access feed info structures */
+
 typedef struct feed {
 	gint		type;			/**< feed type (first position is important!!!) */
 	gpointer	*ui_data;		/**< per-feed UI data (second position is important!!!) */
@@ -71,30 +75,53 @@ typedef struct feed {
 	
 	gchar		*id;			/**< unique feed identifier string */
 	gint		unreadCount;		/**< number of unread items */
+	gint		newCount;		/**< number of new items */
 	gint		defaultInterval;	/**< update interval as specified by the feed */
-	gboolean	available;		/**< flag to signalize loading errors */
+	gint		loaded;			/**< counter which is non-zero if items are to be kept in memory */
+	gboolean	needsCacheSave;		/**< flag set when the feed's cache needs to be resaved */
 	gchar		*parseErrors;		/**< textual/HTML description of parsing errors */
+	gchar		*errorDescription;	/**< textual/HTML description of download/parsing errors */
 	
 	gpointer	icon;			/**< pointer to pixmap, if there is a favicon */
-		
+
+	time_t		time;			/**< Feeds modified date */
+	GHashTable	*tmpdata;		/**< tmp data hash used during stateful parsing */
+			
 	/* feed properties needed to be saved */
+	gboolean	available;		/**< flag to signalize loading errors */
+	gboolean	discontinued;		/**< flag to avoid updating after HTTP 410 */
+
 	gchar		*title;			/**< feed/channel title */
+	gchar		*htmlUrl;		/**< URL of HTML version of the feed */
+	gchar		*imageUrl;		/**< URL of the optional feed image */
 	gchar		*description;		/**< HTML string describing the feed */
 	gchar		*source;		/**< feed source */
 	gchar		*filtercmd;		/**< feed filter command */
 	gint		updateInterval;		/**< user defined update interval in minutes */
-
+	GSList		*metadata;		/**< metadata of this feed */
+	
+	gulong		lastItemNr;		/**< internal counter used to uniqely assign item id's. */
 	GSList		*items;			/**< list of pointers to the item structures of this channel */
 	
-	GSList		*filter;		/**< list of filters applied to this feed */
+	GSList		*rules;			/**< list of rules if this is a vfolder */
 	
-	/* feed properties used for updating */
-	GTimeVal	lastPoll;	/**< time at which the feed was last updated */
-	gboolean	updateRequested;	/**< flag set when update in progress */
-	gpointer	*request;		/**< update request structure */
-
+	/* feed updating state properties */
+	gchar		*lastModified;		/**< Last modified string as sent by the server */
+	gchar		*etag;			/**< E-Tag sent by the server */
+	GTimeVal	lastPoll;		/**< time at which the feed was last updated */
+	GTimeVal	lastFaviconPoll;	/**< time at which the feed was last updated */
+	gchar		*cookies;		/**< cookies to be used */	
+	struct request	*request;		/**< update request structure used when downloading content */
+	GSList		*otherRequests;		/**< list of other update request structures used for downloading anything (favicon, blogChannel stuff, ...) */
+	
+	/* feed cache state properties */
 	gint		cacheLimit;		/**< Amount of cache to save: See the cache_limit enum */
-	gboolean	needsCacheSave;		/**< flag set when the feed's cache needs to be resaved */
+	gboolean	noIncremental;		/**< Do merging for this feed but drop old items */
+	
+	/* feed GUI state properties */
+	gboolean	twoPane;		/**< Flag if three pane or condensed mode is set for this feed */
+	gint		sortColumn;		/**< Sorting column. Set to either IS_TITLE, or IS_TIME */
+	gboolean	sortReversed;		/**< Sort in the reverse order? */
 } *feedPtr;
 
 /* ------------------------------------------------------------ */
@@ -131,6 +158,19 @@ void feed_init(void);
  */
 feedPtr feed_new(void);
 
+/**
+ * General feed source parsing function. Parses the passed feed source
+ * and tries to determine the source type. If the type is HTML and 
+ * autodiscover is TRUE the function tries to find a feed, tries to
+ * download it and parse the feed's source instead of the passed source.
+ *
+ * @param fp		the feed structure to be filled
+ * @param data		the feed source
+ * @param dataLength the length of the 'data' string
+ * @param autodiscover	TRUE if auto discovery should be possible
+ */
+feedHandlerPtr feed_parse(feedPtr fp, gchar *data, size_t dataLength, gboolean autodiscover);
+
 /**
  * Loads a feed from a cache file.
  *
@@ -142,37 +182,48 @@ feedPtr feed_new(void);
  * the cache filename.
  *
  * @returns FALSE if the feed file could not be opened and TRUE if it
- * was opened.
+ * was opened or was already loaded.
  */
-gboolean feed_load_from_cache(feedPtr fp);
+gboolean feed_load(feedPtr fp);
+
+/* Only some feed informations are kept in memory to lower memory
+   usage. This method unloads everything besides necessary infos. */
+void feed_unload(feedPtr fp);
+
 void feed_merge(feedPtr old_fp, feedPtr new_fp);
 void feed_remove(feedPtr fp);
-void feed_schedule_update(feedPtr fp);
+void feed_schedule_update(feedPtr fp, gint flags);
 void feed_save(feedPtr fp);
 
+/**
+ * Can be used to add a single item to a feed. But it's better to
+ * use feed_add_items() to keep the item order of parsed feeds.
+ * Should be used for vfolders only.
+ */
 void feed_add_item(feedPtr fp, itemPtr ip);
 
-void feed_copy(feedPtr fp, feedPtr new_fp);
-void feed_free(feedPtr fp);
-
 /**
- * General feed source parsing function. Parses the passed feed source
- * and tries to determine the source type. If the type is HTML and 
- * autodiscover is TRUE the function tries to find a feed, tries to
- * download it and parse the feed's source instead of the passed source.
- *
- * @param fp		the feed structure to be filled
- * @param data		the feed source
- * @param autodiscover	TRUE if auto discovery should be possible
+ * To be used by parser implementation to merge a new orderd list of
+ * items to a feed. Ensures properly ordered joint item list. The
+ * passed GList is free'd afterwards!
  */
-feedHandlerPtr feed_parse(feedPtr fp, gchar *data, gboolean autodiscover);
+void feed_add_items(feedPtr fp, GList *items);
+
+void feed_remove_item(feedPtr fp, itemPtr ip);
+
+/** 
+ * To lookup an item given by it's unique item nr 
+ */
+itemPtr feed_lookup_item(feedPtr fp, gulong nr);
+
+void feed_free(feedPtr fp);
 
 /**
  * This is a timeout callback to check for feed update results.
  * If there is a result pending its data is parsed and merged
  * against the feed it belongs to.
  */
-gint feed_process_update_results(gpointer data);
+void feed_process_update_result(struct request *request);
 
 /* ------------------------------------------------------------ */
 /* feed property get/set 					*/
@@ -198,7 +249,13 @@ void feed_increase_unread_counter(feedPtr fp);
 void feed_decrease_unread_counter(feedPtr fp);
 gint feed_get_unread_counter(feedPtr fp);
 
+void feed_increase_new_counter(feedPtr fp);
+void feed_decrease_new_counter(feedPtr fp);
+gint feed_get_new_counter(feedPtr fp);
+
 gint feed_get_default_update_interval(feedPtr fp);
+void feed_set_default_update_interval(feedPtr fp, gint interval);
+
 gint feed_get_update_interval(feedPtr fp);
 void feed_set_update_interval(feedPtr fp, gint interval);
 
@@ -207,11 +264,15 @@ void feed_reset_update_counter(feedPtr fp);
 gboolean feed_get_available(feedPtr fp);
 void feed_set_available(feedPtr fp, gboolean available);
 
+gboolean feed_get_discontinued(feedPtr fp);
+void feed_set_discontinued(feedPtr fp, gboolean discontinued);
+
 /**
  * Returns a HTML string describing the last retrieval error 
  * of this feed. Should only be called when getFeedAvailable
- * returns FALSE. Caller must free returned string! 
+ * returns FALSE.
  *
+ * @param fp		feed
  * @return HTML error description
  */
 gchar * feed_get_error_description(feedPtr fp);
@@ -219,19 +280,48 @@ gchar * feed_get_error_description(feedPtr fp);
 const gchar *feed_get_id(feedPtr fp);
 void feed_set_id(feedPtr fp, const gchar *id);
 
+const time_t feed_get_time(feedPtr fp);
+void feed_set_time(feedPtr fp, time_t time);
+
 const gchar * feed_get_title(feedPtr fp);
 void feed_set_title(feedPtr fp, const gchar * title);
 
 const gchar * feed_get_description(feedPtr fp);
+void feed_set_description(feedPtr fp, const gchar *description);
 
 const gchar * feed_get_source(feedPtr fp);
 void feed_set_source(feedPtr fp, const gchar * source);
+
 const gchar * feed_get_filter(feedPtr fp);
 void feed_set_filter(feedPtr fp, const gchar * filter);
 
-GSList * feed_get_item_list(feedPtr fp);
-void feed_clear_item_list(feedPtr fp);
+const gchar * feed_get_html_url(feedPtr fp);
+void feed_set_html_url(feedPtr fp, const gchar *url);
 
-void feed_mark_all_items_read(feedPtr fp);
+const gchar * feed_get_image_url(feedPtr fp);
+void feed_set_image_url(feedPtr fp, const gchar *url);
+
+const gchar * feed_get_lastmodified(feedPtr fp);
+void feed_set_lastmodified(feedPtr fp, const gchar *lastmodified);
+
+const gchar * feed_get_etag(feedPtr fp);
+void feed_set_etag(feedPtr fp, const gchar *etag);
+
+const feedHandlerPtr feed_get_fhp(feedPtr fp);
+
+GSList * feed_get_item_list(feedPtr fp);
+
+void feed_set_sort_column(feedPtr fp, gint sortColumn, gboolean reversed);
+void feed_clear_item_list(feedPtr fp);
+void feed_remove_items(feedPtr fp);
+
+void feed_set_two_pane_mode(feedPtr fp, gboolean newMode);
+gboolean feed_get_two_pane_mode(feedPtr fp);
+
+/** 
+ * Returns a HTML rendering of a feed. The returned string must be
+ *  freed
+ */
+gchar *feed_render(feedPtr fp);
 
 #endif
