@@ -28,6 +28,10 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
+#ifdef HAVE_CONFIG_H
+#  include <config.h>
+#endif
+
 #include <libgtkhtml/gtkhtml.h>
 #include <stdlib.h>
 #include <string.h>
