@@ -19,6 +19,10 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
+#ifdef HAVE_CONFIG_H
+#  include <config.h>
+#endif
+
 #include <stdlib.h>
 #include <string.h>
 #include "support.h"
@@ -62,8 +66,10 @@ static gchar *checkLinkRefForFavicon(const gchar* str) {
 	if(NULL == tmp) return NULL;
 	/* FIXME: single quotes support */
 	tmp2 = strchr(tmp, '\"');
+	
 	if(NULL == tmp2) return NULL;
 	tmp = strchr(tmp2+1, '\"');
+	if (tmp == NULL) return NULL;
 	*tmp = '\0';
 	res = g_strdup(tmp2+1);
 	*tmp = '\"';
@@ -87,6 +93,7 @@ static gchar *checkNormalLink(const gchar* str) {
 	tmp2 = strchr(tmp, '\"');
 	if(NULL == tmp2) return NULL;
 	tmp = strchr(tmp2+1, '\"');
+	if (tmp == NULL) return NULL;
 	*tmp = '\0';
 	res = g_strdup(tmp2+1);
 	*tmp = '\"';
