@@ -19,6 +19,10 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
+#ifdef HAVE_CONFIG_H
+#  include <config.h>
+#endif
+
 #include <glib.h>
 #include <time.h>
 #include <string.h> /* For memset() */
@@ -287,7 +291,7 @@ gchar *item_render(itemPtr ip) {
 		
 	/* add the date before the other meta-data */
 	addToHTMLBufferFast(&buffer, FEED_FOOT_FIRSTTD);
-	addToHTMLBufferFast(&buffer, _("Date"));
+	addToHTMLBufferFast(&buffer, _("date"));
 	addToHTMLBufferFast(&buffer, FEED_FOOT_NEXTTD);
 	tmp = ui_itemlist_format_date(ip->time);
 	addToHTMLBufferFast(&buffer, tmp);
