@@ -27,6 +27,10 @@
  *
  */
  
+#ifdef HAVE_CONFIG_H
+#  include <config.h>
+#endif
+
 #include <string.h>
 #include <iconv.h>
 #include <stdio.h>
