@@ -19,6 +19,10 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
  
+#ifdef HAVE_CONFIG_H
+#  include <config.h>
+#endif
+
 #include <gtk/gtk.h>
 #include <libxml/uri.h>
 #include "support.h"
@@ -558,7 +562,7 @@ static void on_selectfile_pressed(GtkButton *button, gpointer user_data) {
 	}
 	
 	name = g_filename_from_utf8(utfname,-1,NULL, NULL, NULL);
-	ui_choose_file(_("Choose File"), GTK_WINDOW(ui_data->dialog), GTK_STOCK_OPEN, FALSE, on_selectfileok_clicked, name, ui_data);
+	ui_choose_file(_("Choose File"), GTK_WINDOW(ui_data->dialog), GTK_STOCK_OPEN, FALSE, on_selectfileok_clicked, name, name, ui_data);
 	g_free(name);
 }
  
