@@ -19,6 +19,10 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA 
  */
 
+#ifdef HAVE_CONFIG_H
+#  include <config.h>
+#endif
+
 #include <errno.h>
 #include <unistd.h>
 #include <sys/types.h>
@@ -367,6 +371,10 @@ void ui_feedlist_select(nodePtr np) {
  	} else {
 		selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(treeview));
 		gtk_tree_selection_unselect_all(selection);
+		/* The code to clear the itemlist when something is
+		   unselected is disabled... so we must clear the itemlist
+		   explicitly here*/
+		itemlist_load(NULL);
 	}
 	
 	gtk_window_set_focus(GTK_WINDOW(mainwindow), focused);
@@ -461,6 +469,11 @@ void on_popup_allunread_selected(void) {
 	}
 }
 
+void on_popup_allfeedsunread_selected(void) {
+
+	ui_feedlist_do_for_all(NULL, ACTION_FILTER_FEED, itemlist_mark_all_read);
+}
+
 void on_popup_mark_as_read(gpointer callback_data, guint callback_action, GtkWidget *widget) {
 
 	on_popup_allunread_selected();
@@ -511,7 +524,7 @@ static void ui_feedlist_delete_response_cb(GtkDialog *dialog, gint response_id,
 	switch(response_id) {
 	case GTK_RESPONSE_YES:
 		ui_feedlist_select(NULL);
-		ui_itemlist_clear();
+		itemlist_load(NULL);
 		ui_feedlist_delete_(ptr);
 	}
 	gtk_widget_destroy(GTK_WIDGET(dialog));
