@@ -455,6 +455,8 @@ gboolean on_close(GtkWidget *widget, GdkEvent *event, gpointer user_data) {
 		return on_quit(widget, event, user_data);
 	ui_mainwindow_save_position();
 	gtk_widget_hide(mainwindow);
+	if (!startIconified)
+		session_set_cmd(NULL, TRUE);
 	return TRUE;
 }
 
@@ -532,24 +534,28 @@ static void ui_choose_file_cb_canceled(GtkButton *button, gpointer user_data) {
 }
 #endif
 
-void ui_choose_file(gchar *title, GtkWindow *parent, gchar *buttonName, gboolean saving, fileChoosenCallback callback, const gchar *filename, gpointer user_data) {
+static void ui_choose_file_or_dir(gchar *title, GtkWindow *parent, gchar *buttonName, gboolean saving, gboolean directory, fileChoosenCallback callback, const gchar *currentFilename, const gchar *filename, gpointer user_data) {
 	GtkWidget			*dialog;
 	struct file_chooser_tuple	*tuple;
-#if GTK_CHECK_VERSION(2,4,0)
 	GtkWidget			*button;
-	
+
+	g_assert(TRUE != (saving & directory));
+g_print("file/dir chooser: saving=%s directory=%s currentFile=%s file=%s data=%d\n", saving?"TRUE":"FALSE", directory?"TRUE":"FALSE", currentFilename, filename, user_data);
+#if GTK_CHECK_VERSION(2,4,0)
 	dialog = gtk_file_chooser_dialog_new(title,
 	                                     parent,
-	                                     saving ? GTK_FILE_CHOOSER_ACTION_SAVE : GTK_FILE_CHOOSER_ACTION_OPEN,
+	                                     (directory?GTK_FILE_CHOOSER_ACTION_SELECT_FOLDER:
+					      (saving ? GTK_FILE_CHOOSER_ACTION_SAVE : GTK_FILE_CHOOSER_ACTION_OPEN)),
 	                                     GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
 	                                     NULL);
 	gtk_window_set_modal(GTK_WINDOW(dialog), TRUE);
-
+	if(NULL != currentFilename)
+		gtk_file_chooser_set_current_name(GTK_FILE_CHOOSER(dialog), currentFilename);
 	tuple = g_new0(struct file_chooser_tuple, 1);
 	tuple->dialog = dialog;
 	tuple->func = callback;
 	tuple->user_data = user_data;
-
+	
 	button = gtk_dialog_add_button(GTK_DIALOG(dialog), buttonName, GTK_RESPONSE_ACCEPT);
 	GTK_WIDGET_SET_FLAGS(button, GTK_CAN_DEFAULT);
 	gtk_widget_grab_default(button);
@@ -571,7 +577,10 @@ void ui_choose_file(gchar *title, GtkWindow *parent, gchar *buttonName, gboolean
 
 	if(filename != NULL)
 		gtk_file_selection_set_filename(GTK_FILE_SELECTION(dialog), filename);
-	
+		
+	if(TRUE == directory)
+		gtk_file_selection_hide_fileop_buttons(GTK_FILE_SELECTION(dialog));
+		
 	g_signal_connect(GTK_FILE_SELECTION(dialog)->ok_button,
 	                 "clicked",
 	                 G_CALLBACK(ui_choose_file_cb),
@@ -585,3 +594,14 @@ void ui_choose_file(gchar *title, GtkWindow *parent, gchar *buttonName, gboolean
 	gtk_widget_show_all(dialog);
 #endif
 }
+
+void ui_choose_file(gchar *title, GtkWindow *parent, gchar *buttonName, gboolean saving, fileChoosenCallback callback, const gchar *currentFilename, const gchar *filename, gpointer user_data) {
+
+	ui_choose_file_or_dir(title, parent, buttonName, saving, FALSE, callback, currentFilename, filename, user_data);
+}
+
+void ui_choose_directory(gchar *title, GtkWindow *parent, gchar *buttonName, fileChoosenCallback callback, const gchar *currentFilename, const gchar *filename, gpointer user_data) {
+
+	ui_choose_file_or_dir(title, parent, buttonName, FALSE, TRUE, callback, currentFilename, filename, user_data);
+}
+
