@@ -23,6 +23,10 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
+
+#ifdef HAVE_CONFIG_H
+#  include <config.h>
+#endif
  
 #include <gtk/gtk.h>
 #include "ui_queue.h"
